# Расписание специалиста

**GET**: `https://api3.medelement.com/v1/timetable/get_timetable`

## Параметры:

| Название       | Тип           | Описание          |
| -------------- | ------------- | ----------------- |
| date[]         | Array of date | Массив с периодом |
| specialistCode | Bigint        | Код специалиста   |

## Ответ:

HTTP/1.1 200 OK

```json
{
    "14.10.2024": {
        "timetable": [],
        "clinicWorkingHours": {
            "start": "14.10.2024 00:00",
            "end": "14.10.2024 00:00"
        },
        "specialistWorkingHours": "day off"
    },
    "15.10.2024": {
        "timetable": [
            {
                "start": "15.10.2024 08:00:00",
                "end": "15.10.2024 09:30:00",
                "working": false
            },
            {
                "start": "15.10.2024 09:30:00",
                "end": "15.10.2024 11:00:00",
                "working": true
            },
            {
                "start": "15.10.2024 11:00:00",
                "end": "15.10.2024 12:30:00",
                "working": true
            },
            {
                "start": "15.10.2024 12:30:00",
                "end": "15.10.2024 14:00:00",
                "working": false
            },
            {
                "start": "15.10.2024 14:00:00",
                "end": "15.10.2024 15:30:00",
                "working": false
            }
        ],
        "clinicWorkingHours": {
            "start": "15.10.2024 00:00",
            "end": "15.10.2024 23:59"
        },
        "specialistWorkingHours": {
            "start": "15.10.2024 08:00:00",
            "end": "15.10.2024 16:00:00",
            "start_lunch": "15.10.2024 13:00:00",
            "end_lunch": "15.10.2024 14:00:00",
            "time_off": [
                {
                    "start": "15.10.2024 14:30:00",
                    "end": "15.10.2024 15:00:00"
                },
                {
                    "start": "15.10.2024 09:00:00",
                    "end": "15.10.2024 09:30:00"
                }
            ]
        }
    }
}
```

## Описание полей ответа:

| Название               | Тип             | Описание                 |
| ---------------------- | --------------- | ------------------------ |
| timetable              | Array of object | Слоты времени на запись  |
| specialistWorkingHours | Array of object | Время работы специалиста |
| clinicWorkingHours     | Array of object | Время работы клиники     |

### Объект timetable (список слотов на запись):

| Название | Тип      | Описание                                 |
| -------- | -------- | ---------------------------------------- |
| start    | Datetime | Время начала приема                      |
| end      | Datetime | Время окончания приема                   |
| working  | Boolean  | Работает ли специалист в указанное время |

### Объект clinicWorkingHours:

| Название | Тип      | Описание               |
| -------- | -------- | ---------------------- |
| start    | Datetime | Время начала работы    |
| end      | Datetime | Время окончания работы |

### Объект specialistWorkingHours:

| Название    | Тип             | Описание                                                          |
| ----------- | --------------- | ----------------------------------------------------------------- |
| start       | Datetime        | Время начала работы                                               |
| end         | Datetime        | Время окончания работы                                            |
| start_lunch | Datetime        | Время начала обеда                                                |
| end_lunch   | Datetime        | Время окончания обеда                                             |
| time_off    | Array of object | Массив с объектами нерабочего времени врача вне основного графика |
